summaryrefslogtreecommitdiff
path: root/include/vcl/threadex.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/vcl/threadex.hxx')
-rw-r--r--include/vcl/threadex.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/vcl/threadex.hxx b/include/vcl/threadex.hxx
index 39c1633d2054..af2978ce3bdb 100644
--- a/include/vcl/threadex.hxx
+++ b/include/vcl/threadex.hxx
@@ -24,7 +24,7 @@
#include <tools/link.hxx>
#include <vcl/dllapi.h>
-#include <o3tl/optional.hxx>
+#include <optional>
#include <memory>
namespace vcl
@@ -84,9 +84,9 @@ private:
#else
FuncT const m_func;
#endif
// using o3tl::optional here omits the need that ResultT is default
// constructable:
- ::o3tl::optional<ResultT> m_result;
+ ::std::optional<ResultT> m_result;
};
template <typename FuncT>
@@ -84,9 +84,9 @@ private:
FuncT const m_func;
#endif
- // using o3tl::optional here omits the need that ResultT is default
+ // using std::optional here omits the need that ResultT is default
// constructable: